---
slug: /exception-handling-statement
---

# Overview

Special conditions may occur during the execution of stored programs and require handling, such as exiting the current program block. Users can define handlers for conditions like warnings or exceptions or specify error codes.

seekdb supports the following PL exception handling statements:

* The `DECLARE ... CONDITION` statement is used to name an exception condition. For more information, see [DECLARE ... CONDITION](../900.pl-exception-handling-statement/200.declare-condition.md).

* The `DECLARE ... HANDLER` statement is used to declare a handler. For more information, see [DECLARE ... HANDLER](../900.pl-exception-handling-statement/300.declare-handler.md).

* The `RESIGNAL` statement is used to modify the exception information in the handler. For more information, see [RESIGNAL](../900.pl-exception-handling-statement/500.resignal.md).

* The `SIGNAL` statement is used to raise an exception condition. For more information, see [SIGNAL](../900.pl-exception-handling-statement/600.signal.md).

* The `GET DIAGNOSTICS` statement is used to retrieve information from the diagnostic area. For more information, see [GET DIAGNOSTICS](../900.pl-exception-handling-statement/400.get-diagnostics.md).

Information on how the server selects a handler when an exception condition occurs. For more information, see [Handler Scope](../900.pl-exception-handling-statement/700.scope-rules-for-handlers.md).

For information about the diagnostic area, see [Diagnostic Area](../900.pl-exception-handling-statement/800.diagnostic-area.md).